@@ -133,8 +133,6 @@ class AlertCreator:
         notification_message: str,
         metadata: Optional[Dict] = None,
     ) -> Union[List, List[Event]]:
-        if metadata is None:
-            metadata = {}
         counter = 0
         written_events = []
         if len(non_duplicated_new_events) > 0:
@@ -205,8 +203,6 @@ class AlertCreator:
             int: Updated end when more events than max_events_to_be_processed. Use as new end.
 
         """
-        if metadata is None:
-            metadata = {}
         self._validate_df(df)
         if isinstance(df, pd.DataFrame):
             possible_events = self._create_deviation_events_from_pandas(df)
@@ -328,7 +324,9 @@ class AlertCreator:
         existing_events.sort(key=lambda e: e.start_time)
         remaining_new_events: List = []
         # first remove new alerts that are exactly the same
-        existing_open_events = list(filter(lambda e: e.end_time is None, existing_events))
+        existing_open_events = list(
+            filter(lambda e: e.end_time is None or e.end_time > end - self.merge_period, existing_events)
+        )
         if len(existing_open_events) == 0:
             return [], new_events
 
